import type { JudoAuthorization, JudoConfiguration, JudoResponse, JudoTransactionMode, JudoTransactionType } from '../types';
export declare class JudoPay {
    private readonly authorization;
    /**
     * This property is used to toggle the sandbox environment on and off.
     * You can use the sandbox environment to test our SDK features.
     */
    isSandboxed: boolean;
    /**
     * The designated initializer that is used to configure the JudoPay session, based
     * on a provided object that implements the JudoAuthorization interface.
     *
     * @param authorization - can be either a JudoBasicAuthorization (token & secret) or
     * a JudoSessionAuthorization (token & payment session) instance.
     */
    constructor(authorization: JudoAuthorization);
    /**
     * A method used to verify if ApplePay is supported for given configuration object
     *
     * This needs to be invoked before invoking ApplePay transactions.
     *
     * @returns an asynchronous boolean value that indicates if ApplePay is available.
     */
    isApplePayAvailableWithConfiguration(configuration: JudoConfiguration): Promise<boolean>;
    /**
     * A method for invoking the Judo UI for card transactions.
     * Supported operations - payments, pre-auths, register card, save card, check card.
     *
     * @param type - a JudoTransactionType value that defines the transaction type.
     * @param configuration - a JudoConfiguration object that is used to configure/customize the payment flow.
     *
     * @returns an asynchronous JudoResponse object, containing the transaction results.
     */
    invokeTransaction(type: JudoTransactionType, configuration: JudoConfiguration): Promise<JudoResponse>;
    fetchTransactionDetails(receiptId: string): Promise<JudoResponse>;
    /**
     * A method for completing a payment/pre-auth transaction using a saved card token.
     *
     * @param mode - a JudoTransactionMode value that defines if the transaction is either a payment or pre-auth.
     * @param configuration - a JudoConfiguration object that is used to configure/customize the payment flow.
     * @param cardToken - the saved card token string.
     * @param securityCode - the saved card token security code.
     * @param cardholderName - the saved card token cardholder name.
     * @param cardScheme - the saved card token scheme name.
     *
     * @returns an asynchronous JudoResponse object, containing the transaction results.
     */
    performTokenTransaction(mode: JudoTransactionMode, configuration: JudoConfiguration, cardToken: string, securityCode: string | undefined | null, cardholderName: string | undefined | null, cardScheme: string): Promise<JudoResponse>;
    /**
     * A method for invoking Apple Pay transactions.
     * For this transaction to work, the required JudoApplePayConfiguration parameters must be present as part of
     * the JudoConfiguration object passed to the method.
     *
     * @param mode - a JudoTransactionMode value that defines if the transaction is either a payment or pre-auth.
     * @param configuration - a JudoConfiguration object that is used to configure/customize the payment flow.
     *
     * @returns an asynchronous JudoResponse object, containing the transaction results.
     */
    invokeApplePay(mode: JudoTransactionMode, configuration: JudoConfiguration): Promise<JudoResponse>;
    /**
     * A method for invoking Google Pay transactions.
     * For this transaction to work, the required JudoGooglePayConfiguration parameters must be present as part of
     * the JudoConfiguration object passed to the method.
     *
     * @param mode - a JudoTransactionMode value that defines if the transaction is either a payment or pre-auth.
     * @param configuration - a JudoConfiguration object that is used to configure/customize the payment flow.
     *
     * @returns an asynchronous JudoResponse object, containing the transaction results.
     */
    invokeGooglePay(mode: JudoTransactionMode, configuration: JudoConfiguration): Promise<JudoResponse>;
    /**
     * A method for invoking the Judo wallet, allowing users to pay with their preferred payment method.
     * (Cards, Apple Pay/Google Pay, iDEAL)
     *
     * @param mode - a JudoTransactionMode value that defines if the transaction is either a payment or pre-auth.
     * @param configuration - a JudoConfiguration object that is used to configure/customize the payment flow.
     *
     * @returns an asynchronous JudoResponse object, containing the transaction results.
     */
    invokePaymentMethodScreen(mode: JudoTransactionMode, configuration: JudoConfiguration): Promise<JudoResponse>;
    private readonly generateJudoParameters;
    private readonly generateTransactionTypeParameters;
    private readonly generateTransactionModeParameters;
    private readonly generateAuthorizationParameters;
}
//# sourceMappingURL=index.d.ts.map